import numpy as np

from .data.load_data import load_star_temperatures, load_star_brightness

from.zodiac import black_body_phot

#на вход подаем галактические координаты (l -- долгота, b -- широта) и массив длин волн, по которым строим спектр
#РАЗОБРАТЬСЯ С КОЭФФИЦИЕНТАМИ А -- НАДО ЛИ НОРМИРОВАТЬ НА C (КАЖЕТСЯ НАДО) А ЕЩЕ ВРОДЕ Я ЕГО ОТНОРМИРОВАЛА И ПОДГРУЗИЛА -- ПРОВЕРИТЬ
def star_spectrum(l, b, lmbd):
    """
    Вычисляет спектр звезды по её галактическим координатам и массиву длин волн.

    Функция принимает галактические координаты (долгота и широта) и массив длин волн,
    пересчитывает координаты в индексы массива, извлекает температуру и амплитуду 
    из предварительно рассчитанных массивов данных, и вычисляет спектр звезды 
    с использованием формулы Планка для абсолютно черного тела.

    Параметры:
        l (float): Галактическая долгота точки наблюдения (в градусах).
        b (float): Галактическая широта точки наблюдения (в градусах).
        lmbd (ndarray): Массив длин волн, для которых рассчитывается спектр (в нм).

    Возвращает:
        ndarray: Массив значений спектра звезды (в фот / (сек * м^2 * нм)).

    Примечания:
        - Пересчет галактических координат в индексы массива:
            - Долгота преобразуется в диапазон от 0 до 3600.
            - Широта преобразуется в диапазон от 0 до 1800.
        - Используются два предварительно рассчитанных массива:
            - `star_brightness`: массив амплитуд яркости звезд.
            - `star_temperatures`: массив температур звезд (в Кельвинах).
        - Спектр рассчитывается по формуле Планка для абсолютно черного тела:
            - spectrum = A * black_body_phot(lmbd, T),
            где A — амплитуда, T — температура, lmbd — длина волны.
        - Функция `black_body_phot` определена отдельно.
        - Учитывается порядок амплитуды с помощью множителя 1e-30


    Зависимости:
        - `load_star_brightness()`: загружает массив амплитуд яркости звезд.
        - `load_star_temperatures()`: загружает массив температур звезд.
        - `black_body_phot(lmbd, T)`: вычисляет спектральную плотность излучения 
          абсолютно черного тела для заданной длины волны и температуры.
    """
    #пересчет из галактических к позиции в массиве, ЕСЛИ ПРОБЛЕМЫ ВОЗНИКЛИ, ПЕРЕПРОВЕРИТЬ
    if round(l*10) >= 1800:
        j = int((1800 - round(l*10)) + 3600)
    elif round(l*10) < 1800:
        j =  int(1800 - round((l+10)*10))
     
    i = int(900 + round(b*10))
    star_brightness = load_star_brightness()
    star_temperatures = load_star_temperatures()    
    A = star_brightness[i][j] #учитывается порядок амплитуды, которая хранится в больших числах
    T = star_temperatures[i][j]
    print('Информация по звезде в этом пикселе: T = ', T, ', A = ', A, sep='')
    print('Техническая строчка: i = ', i, ', j = ', j, sep='')
    spectrum = A * black_body_phot(lmbd, T) * 10**(-30) 
    return spectrum